pub enum ConfigError {
NonDirExpr,
NonTableExpr,
NonTableConfig {
lib: Symbol,
},
UnsupportedDirKey {
key: Expr,
},
InvalidLibId {
id: String,
},
InvalidPathSegment {
segment: String,
},
MissingField {
key: String,
},
TypeMismatch {
key: String,
expected: &'static str,
},
}Expand description
Error reported by config table, view, and path helpers.
Variants
NonDirExpr
A Dir expression was not an Expr::Map.
NonTableExpr
A table expression was not an Expr::Map.
NonTableConfig
A Dir entry for lib did not contain a table value.
UnsupportedDirKey
A Dir key could not be interpreted as a library id.
InvalidLibId
A library id or id segment is not safe for config use.
InvalidPathSegment
A library config path segment was rejected.
MissingField
A required field was absent from a config table.
TypeMismatch
A config field had a different shape than the caller requested.