Module keys

Module keys 

Canonical config field identity helpers.

Functions

config_field_name
Returns the canonical unqualified config field name represented by key.
same_config_field
Returns true when two keys identify the same config field.