pub struct ConfigLayer {
pub source: ConfigSource,
pub dir: ConfigDir,
}Expand description
One configuration layer and the source that produced it.
Fields
source: ConfigSourceSource metadata for this layer.
dir: ConfigDirDir data carried by this layer.
Implementations
Sourceimpl ConfigLayer
impl ConfigLayer
Sourcepub fn new(source: ConfigSource, dir: ConfigDir) -> Self
pub fn new(source: ConfigSource, dir: ConfigDir) -> Self
Creates a new layer from source metadata and Dir data.