ConfigDir

Struct ConfigDir 

pub struct ConfigDir {
    pub entries: Vec<ConfigTable>,
}
A configuration Dir: library id to table.

Fields

entries: Vec<ConfigTable>

Tables carried by this Dir.

Implementations

Source

impl ConfigDir

pub fn new() -> Self

Creates an empty Dir.

pub fn one(lib: Symbol, table: Expr) -> ConfigResult<Self>

Creates a Dir with one library table.

pub fn table(&self, lib: &Symbol) -> Option<&ConfigTable>

Finds a table by library id.

pub fn table_mut(&mut self, lib: &Symbol) -> Option<&mut ConfigTable>

Finds a mutable table by library id.

pub fn upsert(&mut self, table: ConfigTable)

Inserts or replaces a table for its library id.

pub fn from_dir_expr(expr: &Expr) -> ConfigResult<Self>

Builds a Dir from a map of library id keys to table values.

pub fn to_expr(&self) -> Expr

Converts this Dir back to a kernel map expression.