ConfigView

Struct ConfigView 

pub struct ConfigView<'a> { /* private fields */ }
Borrowed typed accessors over one config table.

Implementations

Source

impl<'a> ConfigView<'a>

pub fn new(table: &'a ConfigTable) -> Self

Creates a view over table.

pub fn from_entries(entries: &'a [(Expr, Expr)]) -> Self

Creates a view over already-borrowed table entries.

pub fn get(&self, key: &str) -> Option<&'a Expr>

Returns the raw expression for key.

pub fn string(&self, key: &str) -> Option<&'a str>

Reads an optional string field.

pub fn required_string(&self, key: &str) -> ConfigResult<&'a str>

Reads a required string field.

pub fn bool(&self, key: &str) -> Option<bool>

Reads an optional boolean field.

pub fn required_bool(&self, key: &str) -> ConfigResult<bool>

Reads a required boolean field.

pub fn i64(&self, key: &str) -> Option<i64>

Reads an optional integer field.

pub fn required_i64(&self, key: &str) -> ConfigResult<i64>

Reads a required integer field.

pub fn list(&self, key: &str) -> Option<&'a [Expr]>

Borrows a list field.

pub fn table(&self, key: &str) -> Option<&'a [(Expr, Expr)]>

Borrows a nested table field.

pub fn string_array(&self, key: &str) -> ConfigResult<Vec<String>>

Reads an optional list of string values.

Missing fields read as an empty vector so callers can treat absent arrays as the natural zero value. A present non-list field, or any non-string list item, is reported as a type mismatch.

pub fn tables(&self, key: &str) -> ConfigResult<Vec<ConfigView<'a>>>

Reads an optional repeated table field as borrowed table views.

Config codecs represent [[name]] repeated tables as a list of map expressions. Missing fields read as an empty vector. A present field must be a list whose items are maps.