Canonical config field identity helpers.
Functions
- config_
field_ name - Returns the canonical unqualified config field name represented by
key. - same_
config_ field - Returns true when two keys identify the same config field.
Canonical config field identity helpers.
key.