pub struct ConfigDir {
pub entries: Vec<ConfigTable>,
}Expand description
A configuration Dir: library id to table.
Fields
entries: Vec<ConfigTable>Tables carried by this Dir.
Implementations
Sourceimpl ConfigDir
impl ConfigDir
Sourcepub fn one(lib: Symbol, table: Expr) -> ConfigResult<Self>
pub fn one(lib: Symbol, table: Expr) -> ConfigResult<Self>
Creates a Dir with one library table.
Sourcepub fn table(&self, lib: &Symbol) -> Option<&ConfigTable>
pub fn table(&self, lib: &Symbol) -> Option<&ConfigTable>
Finds a table by library id.
Sourcepub fn table_mut(&mut self, lib: &Symbol) -> Option<&mut ConfigTable>
pub fn table_mut(&mut self, lib: &Symbol) -> Option<&mut ConfigTable>
Finds a mutable table by library id.
Sourcepub fn upsert(&mut self, table: ConfigTable)
pub fn upsert(&mut self, table: ConfigTable)
Inserts or replaces a table for its library id.
Sourcepub fn from_dir_expr(expr: &Expr) -> ConfigResult<Self>
pub fn from_dir_expr(expr: &Expr) -> ConfigResult<Self>
Builds a Dir from a map of library id keys to table values.